@@ -30,7 +30,8 @@ test_that('intModel is able to initialize a dataSDM object as well as correctly
   PA$species <- sample(x = c('bird'), nrow(PA@data), replace = TRUE)
   mesh <- INLA::inla.mesh.2d(boundary = INLA::inla.sp2segment(SpatialPoly), 
                              max.edge = 2)
-  iPoints <- inlabru::ipoints(samplers = SpatialPoly, domain = mesh)
+  #iPoints <- inlabru::ipoints(samplers = SpatialPoly, domain = mesh)
+  iPoints <- inlabru::ipoints(samplers = SpatialPoly)
   ##Make PA a data.frame object
   PA <- data.frame(PA)
   
